Struct simple_pub_sub::topics::TopicMap
source · pub struct TopicMap {
pub map: BTreeMap<String, HashMap<String, Sender<Msg>>>,
}Expand description
The TopicMap struct is used to store the channels for a given topic.
Fields
map: BTreeMap<String, HashMap<String, Sender<Msg>>>Implementations
sourceimpl TopicMap
impl TopicMap
sourcepub fn query(&self, topic: String) -> String
pub fn query(&self, topic: String) -> String
Returns the number of connected clients for a given topic.
sourcepub fn add_channel(
&mut self,
topic: String,
client_id: String,
channel: Sender<Msg>,
)
pub fn add_channel( &mut self, topic: String, client_id: String, channel: Sender<Msg>, )
Adds a channel to the map.
sourcepub fn remove_channel(&mut self, topic: String, client_id: String)
pub fn remove_channel(&mut self, topic: String, client_id: String)
Removes a channel from the map.