pub struct Client {
pub server: String,
pub port: u16,
}
9
10
11
12
13
14
15
16
17
18
19
async fn main() -> Result<(), String> {
let mut client = simple_pub_sub::client::Client::new("localhost".to_string(), 6480);
client.on_message(on_msg);
let _ = client.connect().await;
let _ = client.subscribe("abc".to_string()).await;
Ok(())
}
9
10
11
12
13
14
15
16
17
18
19
async fn main() -> Result<(), String> {
let mut client = simple_pub_sub::client::Client::new("localhost".to_string(), 6480);
client.on_message(on_msg);
let _ = client.connect().await;
let _ = client.subscribe("abc".to_string()).await;
Ok(())
}
9
10
11
12
13
14
15
16
17
18
19
async fn main() -> Result<(), String> {
let mut client = simple_pub_sub::client::Client::new("localhost".to_string(), 6480);
client.on_message(on_msg);
let _ = client.connect().await;
let _ = client.subscribe("abc".to_string()).await;
Ok(())
}
9
10
11
12
13
14
15
16
17
18
19
async fn main() -> Result<(), String> {
let mut client = simple_pub_sub::client::Client::new("localhost".to_string(), 6480);
client.on_message(on_msg);
let _ = client.connect().await;
let _ = client.subscribe("abc".to_string()).await;
Ok(())
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.